// (C) Copyright 2015 Moodle Pty Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { CoreSharedModule } from '@/core/shared.module';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { CoreCommentsComponentsModule } from '@features/comments/components/components.module';
import { CoreCompileHtmlComponentModule } from '@features/compile/components/compile-html/compile-html.module';
import { CoreRatingComponentsModule } from '@features/rating/components/components.module';
import { CanLeaveGuard } from '@guards/can-leave';
import { AddonModDataComponentsCompileModule } from './components/components-compile.module';
import { AddonModDataComponentsModule } from './components/components.module';
import { AddonModDataEditPage } from './pages/edit/edit';
import { AddonModDataEntryPage } from './pages/entry/entry';
import { AddonModDataIndexPage } from './pages/index/index';

const routes: Routes = [
    {
        path: ':courseId/:cmId',
        component: AddonModDataIndexPage,
    },
    {
        path: ':courseId/:cmId/edit',
        component: AddonModDataEditPage,
        canDeactivate: [CanLeaveGuard],
    },
    {
        path: ':courseId/:cmId/edit/:entryId',
        component: AddonModDataEditPage,
        canDeactivate: [CanLeaveGuard],
    },
    {
        path: ':courseId/:cmId/:entryId',
        component: AddonModDataEntryPage,
    },
];

@NgModule({
    imports: [
        RouterModule.forChild(routes),
        CoreSharedModule,
        AddonModDataComponentsModule,
        AddonModDataComponentsCompileModule,
        CoreCommentsComponentsModule,
        CoreRatingComponentsModule,
        CoreCompileHtmlComponentModule,
    ],
    declarations: [
        AddonModDataIndexPage,
        AddonModDataEntryPage,
        AddonModDataEditPage,
    ],
})
export class AddonModDataLazyModule {}
